@@ -43,7 +43,6 @@ my $runlevel_cmd = '/sbin/runlevel';
 
 my $DATA_DIR = "/var/lib/bum/";
 my $DATA_FILE = $DATA_DIR."numbers";
-my $LOCK_FILE = "/var/lock/bum";
 my $PKGS_FILE = $DATA_DIR."packages";
 
 my @unselects = ("\^\\\.\$", "\^\\\.\\\.\$", "\^rc\$", "\^rcS\$", "\^README\$",
@@ -66,16 +65,6 @@ sub get_full_list
  my @list;
  my $element;
 
- if (!(-d $DATA_DIR)) { `mkdir -p $DATA_DIR`;}
-
- $g_rcdf = &read_rcd_default(root_dir=>$ETC_DIR);
- $g_data = &read_data(file=>$DATA_FILE);
- $g_default = &select_default(rcdf=>$g_rcdf, data=>$g_data);  			#scripts ON
- $g_initd = &read_initd_dir(root_dir=>$ETC_DIR);
- $g_initd = &select_unlinked_initd(initd=>$g_initd, rcdf=>$g_rcdf,		
-                                unselects=>\@unselects);							#scripts off
-
- &write_data(file=>$DATA_FILE, data=>$g_data);
 
 
 # Get list & service number in runlevels
@@ -86,7 +75,8 @@ foreach my $i (@$g_default) {
 	if($arr->[7] ne '-01'){next;}; #skip if S  in rcS 
         $element ="1,".$i.",";
         for (my $y=0; $y<7; $y++) {
-		if ($arr->[$y] eq '-01' && $arr->[$y+10] eq '-01') {$element.="---,"; next;}
+		if ($arr->[$y] eq '-01' && $arr->[$y+10] eq '-01') 
+					{$element.="---,"; next;}
 		if ($arr->[$y] ne '-01') {$element.="S".$arr->[$y].",";}
 	        if ($arr->[$y+10] ne '-01') {$element.="K".$arr->[$y+10].",";}
             }
@@ -118,7 +108,7 @@ foreach my $i (@$g_initd) {
             }
         push (@list,$element);
   }
-					##########
+					
   return \@list;
 }
 
@@ -130,9 +120,7 @@ sub get_full_rcS_list
  	my @list;
 	my $element;
 	
-	$g_rcS = &select_rcS(rcdf=>$g_rcdf, data=>$g_data);				#rcS on
-	$g_rcSoff=&init_rcSoff(rcdf=>$g_rcdf);							#rcS off
-#	&write_data(file=>$DATA_FILE, data=>$g_data);
+
 
 # services on
 	foreach my $i (@$g_rcS) {
@@ -244,7 +232,6 @@ sub make_changes
 
   &exec_update($run,on=>\@res_on, off=>\@res_off, data=>$g_data);
  
- # &write_data(file=>$DATA_FILE, data=>$g_data);
 }
 
 ###############
@@ -276,6 +263,45 @@ sub is_already_off
 	return FALSE;
    
 }
+
+##########################################################
+# Return apt-cache info if available
+sub get_cache_info
+{
+	my $key = shift;
+	my $ret = TRUE;
+	my $s_info = "";
+	my $pkg = $key;
+	my $descr = "";
+
+	if ( exists($g_pkgname->{$key}) ) {
+		$pkg = $g_pkgname->{$key};
+	       
+	}
+
+	if ($pkg ne "") {
+       		$s_info = `apt-cache show $pkg`; #dpkg --print-avail
+       		my $start = rindex($s_info,"Description:");
+       		my $end = rindex($s_info,"Bugs");
+		if ($start >= $end) {$end = $start-1;}
+		$s_info=substr($s_info,$start,$end-$start);
+       
+		my @descr =  grep (/^Description:/,split(/\n/,$s_info));
+        	$descr = join(' ',@descr);
+		$descr=~ s/Description: //;
+        	$s_info =~ s/(Description:).*//g;
+        }
+
+	if ($s_info eq "" ) { 
+		$s_info=_("Sorry, no information found for this package.");
+		$pkg=$key;
+		$ret=FALSE;
+		}
+
+	return ($descr,$s_info,$ret);
+
+}
+
 ##################################################################
 # Return info (if available) on script
 
@@ -287,37 +313,15 @@ sub new_get_script_info
 	my $pkg = "";
 	my $descr = "";
 
-	if ( exists($g_pkgname->{$key}) ) {
-		$pkg = $g_pkgname->{$key};
-	       
-	}
+	($descr,$s_info,$ret) = get_cache_info($key);
 
-if ($pkg ne "") {
-       $s_info = `apt-cache show $pkg`; #dpkg --print-avail
-       my $start = rindex($s_info,"Description:");
-       my $end = rindex($s_info,"Bugs");
-	if ($start >= $end) {$end = $start-1;}
-	$s_info=substr($s_info,$start,$end-$start);
-       
-	my @descr =  grep (/^Description:/,split(/\n/,$s_info));
-        $descr = join(' ',@descr);
-	$descr=~ s/Description://;
-        $s_info =~ s/(Description:).*//g;
-        }
-
-	if ($s_info eq "" ) { 
-			$s_info=_("Sorry, no information found for this package.");
-			$pkg=$key;
-			$ret=FALSE;
-			}
-
-	my($summ,$sum_ret) =get_summ_info($key);
+	my($summ,$sum_ret) = get_summ_info($key);
 	if ($sum_ret) {
 		$pkg=$key;
 		$descr=$summ;
 		}
 
-	return ($key.": ".$descr."\n",$s_info,$ret);
+	return ($descr,$s_info,$ret);
 
 
 }
@@ -327,33 +331,21 @@ if ($pkg ne "") {
 #
 sub get_summ_info
 {
-my $key = shift;
+	my $key = shift;
 	my $ret = TRUE;
 	my $s_info = "";
 	my $pkg = "";
 	my $descr = "";
+	my $dummy = "";
 
-#first check in human text
-my $human = bum_init::get_human_text();
-if( exists $human->{$key} ){
-        return ($human->{$key}->{description}, TRUE);
+	#first check in human text
+	my $human = bum_init::get_human_text();
+	if(exists $human->{$key} ){
+        	return ($human->{$key}->{description}, TRUE);
 	}
 
-if ( exists($g_pkgname->{$key}) ) {
-		$pkg = $g_pkgname->{$key};     
-	}
-
-if ($pkg ne "") {
-       $s_info = `apt-cache show $pkg`; #dpkg --print-avail
-	my @descrip =  grep (/^Description:/,split(/\n/,$s_info));
-        $descr = $descrip[0]; #join(' ',@descr);
-	$descr=~ s/Description: //;  
-        }
-
-	if ($descr eq "" ) { 
-			$descr=_("Sorry, no information found for this package.");
-			$ret=FALSE;
-			}
+	#otherwise get cache information
+	($descr,$dummy,$ret) = get_cache_info($key);
 
 	return ($descr,$ret);
 
@@ -439,8 +431,27 @@ sub get_pkg
 sub get_packages
 {
 	my ($key,$pkg);
+	
+	#Main initialization routines
+	
+	#check if /var/lib/bum exists
+	if (!(-d $DATA_DIR)) { `mkdir -p $DATA_DIR`;}
 
-	 if ( -e $PKGS_FILE  )         			#packages file exists
+ 	$g_rcdf = &read_rcd_default(root_dir=>$ETC_DIR);
+	$g_data = &read_data(file=>$DATA_FILE);
+ 	$g_default = &select_default(rcdf=>$g_rcdf, data=>$g_data);  	#scripts ON
+ 	$g_initd = &read_initd_dir(root_dir=>$ETC_DIR);
+ 	$g_initd = &select_unlinked_initd(initd=>$g_initd, rcdf=>$g_rcdf,		
+                                unselects=>\@unselects);			#scripts off
+
+ 	&write_data(file=>$DATA_FILE, data=>$g_data);
+
+	$g_rcS = &select_rcS(rcdf=>$g_rcdf, data=>$g_data);	#rcS on
+	$g_rcSoff=&init_rcSoff(rcdf=>$g_rcdf);			#rcS off
+
+	#######################
+	
+	if ( -e $PKGS_FILE  )        #packages file exists
 	{
 	open(IN, $PKGS_FILE)|| die "Cannot open file $PKGS_FILE !";
 	while(<IN>){
@@ -467,15 +478,16 @@ sub get_packages
 		$g_pkgname->{$key}=get_pkg($key);
 		} 
 	}
-	else									#packages file doesn't exist
+	else					#packages file doesn't exist
 	{
 	foreach my $key(keys %$g_rcdf) {
 		$g_pkgname->{$key}=get_pkg($key);
 		}
 	}
 
-	open(OUT, "> ".$PKGS_FILE) || die "Cannot write file $PKGS_FILE !";		#write package file
-  	foreach  $key (keys(%{$g_pkgname})){
+	#write package file
+	open(OUT, "> ".$PKGS_FILE) || die "Cannot write file $PKGS_FILE !";		
+	foreach  $key (keys(%{$g_pkgname})){
 	    	print OUT $key." ".$g_pkgname->{$key}."\n";
   	
 		}
@@ -701,7 +713,7 @@ sub read_data{
     	next if ( /^\#/ );
 	my ($first,$second,$third) = split;
 			if (!defined($third)) {next;}
-			if ($third =~ /([0-9][0-9])/){next;}		#corrects bug from v.1.2.7
+			if ($third =~ /([0-9][0-9])/){next;}	#corrects bug from v.1.2.7
       			$data->{$third}->{'start'} = $first;
       			$data->{$third}->{'stop'} = $second;
 
@@ -733,7 +745,7 @@ sub select_default{
     $link = $rcdf->{$package}; 
     $start_num = $link->[2];
     $stop_num = $link->[11];
-	$stop_num = $link->[10] if ($stop_num eq '-01');		#if there is no K in RL1, get the one in RL0
+	$stop_num = $link->[10] if ($stop_num eq '-01'); #if there is no K in RL1, get the one in RL0
 
 	#rule S link in 2-3-4-5 AND S/K link in 1, AND K link in 0-6
 	
@@ -909,25 +921,6 @@ foreach $key ( @{$off} ) {
 
 } ## exec_update()
 
-#######################################################################
-## MODULE: make_lock
-
-sub make_lock{
-  if ( -f $LOCK_FILE ) {
-    return (0,$LOCK_FILE);
-  }
-  open(LOCK, "> ".$LOCK_FILE);
-  close(LOCK);
-  return 1;
-} ## make_lock()
-
-#######################################################################
-## MODULE: remove_lock
-
-sub remove_lock{
-##
-  unlink($LOCK_FILE);
-} ## remove_lock
 
 #####################################################################
 # the script is not in the human list: return UNDEF
@@ -1026,6 +1019,16 @@ sub update_link
         or die "Can't symlink $etc_rc$rl.d/$sk$pri$sn to ../init.d/$sn : $!\n";
 }
 
+#########################################
+
+sub check_lock{
+
+	my @pids = `ps -C bum -o pid=`;
+	
+	if (scalar(@pids)>1) {return TRUE;}		
+		else {return FALSE;} 	
+
+}
 
 
 1;
